[![GitHub tag (latest SemVer)](https://img.shields.io/github/v/tag/bussilab/MDRefine)](https://github.com/bussilab/MDRefine/tags)
[![PyPI](https://img.shields.io/pypi/v/MDRefine)](https://pypi.org/project/MDRefine/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/MDRefine)](https://pypi.org/project/MDRefine/)
[![CI](https://github.com/bussilab/MDRefine/workflows/CI/badge.svg)](https://github.com/bussilab/MDRefine/actions?query=workflow%3ACI)

A package to perform refinement of MD simulation trajectories. Documentation can be browsed at [this page](https://bussilab.github.io/doc-MDRefine/)

To install package and dependencies with pip (version from PyPI):

```
pip install MDRefine
```

You can install the development version by cloning the repository and, from its root directory, type:

```
pip install -e .
```

In case you prefer to install MDRefine in a separate environment to avoid polluting your Python installation with unnecessary packages, we recommend using a Python virtual environment

```
python3 -m venv env
source env/bin/activate
pip install MDRefine
```

To load this environment in a new shell, type `source /path/to/env/bin/activate`.